@@ -1,4 +1,4 @@
-define(['wq/app', './config', './templates'],
+define(['wq/app', './config', 'data/templates'],
 function(app, config, templates) {
 
 app.init(config, templates);
